# Generated by Django 4.2 on 2025-03-24 18:54

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('core', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='systemuser',
            name='brand_name',
            field=models.CharField(blank=True, max_length=100, null=True),
        ),
        migrations.AddField(
            model_name='systemuser',
            name='licence',
            field=models.FileField(blank=True, null=True, upload_to='licences/'),
        ),
        migrations.AlterField(
            model_name='systemuser',
            name='is_active',
            field=models.BooleanField(default=False),
        ),
    ]
